@@ -2,6 +2,7 @@ import os
 import numpy as np
 import pytest
 from napari.layers import Image, Points, Labels, Shapes, Vectors
+from napari.utils.colormaps.colormap_utils import ensure_colormap
 from napari_svg import (
     napari_write_image,
     napari_write_labels,
@@ -14,7 +15,6 @@ from napari_svg import (
 @pytest.fixture(params=['image', 'labels', 'points', 'shapes', 'shapes-rectangles', 'vectors'])
 def layer_writer_and_data(request):
     meta_required = False
-    
     if request.param == 'image':
         data = np.random.rand(20, 20)
         layer = Image(data)
@@ -121,3 +121,21 @@ def test_no_write_image_bad_extension(tmpdir, layer_writer_and_data):
 
     # Check file still does not exist
     assert not os.path.isfile(path)
+
+
+@pytest.mark.parametrize('colormap', ('viridis', ensure_colormap('viridis').dict()))
+def test_write_image_colormaps(tmpdir, layer_writer_and_data, colormap):
+    writer, layer_data, _ = layer_writer_and_data
+    layer_data[1]['colormap'] = colormap
+
+    path = os.path.join(tmpdir, 'layer_file.svg')
+
+    # Check file does not exist
+    assert not os.path.isfile(path)
+
+    # Write data
+    return_path = writer(path, layer_data[0], layer_data[1])
+    assert return_path == path
+
+    # Check file now exists
+    assert os.path.isfile(path)
